@@ -75,7 +75,7 @@ def create(ctx, name):
             f'{utils.secure_filename(iteration_name)}({CONFIG_DATA.get("tester")}).xlsm'
         )
         if target_file_path.exists():
-            target_file_path = str(target_file_path).rsplit('.')[0] + str(int(time.time())) + '.xlsm'
+            target_file_path = Path(str(target_file_path).rsplit('.')[0] + str(int(time.time())) + '.xlsm')
         iteration_id = iterations[iteration_name]
         tapd.set_iteration_id(iteration_id)
 
